#ifndef WSCLEAN_SYSTEM_PYTHONFILEPATH_H_
#define WSCLEAN_SYSTEM_PYTHONFILEPATH_H_

#include <string>

namespace wsclean::system {

std::string FindPythonFilePath(const std::string& filename);

}  // namespace wsclean::system

#endif
